@@ -84,24 +84,24 @@ class SlurmAdapter(Adapter):
     # Capabilities / validation
     # ----------------------------
     def handshake(self) -> ServerCapabilities:
-        # Advertise tools this backend can run (must match your tools.yaml)
-        tools = [
-            ToolCapability(tool_id="echo_test", version="1.0", features={}),
-            ToolCapability(
-                tool_id="blastn",
-                version="real",
-                features={"databases": sorted(list((self.config.get("database_map") or {}).keys()))},
-            ),
-        ]
+        blast_cfg = (self.config or {}).get("blast") or {}
+        db_map = blast_cfg.get("database_map") or {}
+        allowed = blast_cfg.get("allowed_databases")
+
+        dbs = list(allowed) if allowed else sorted(db_map.keys())
 
         return ServerCapabilities(
             engines=["slurm"],
-            tools=tools,
-            resources={"max_cpu": int(self.config.get("max_cpu", 20)), "max_ram_gb": int(self.config.get("max_ram_gb", 128))},
+            tools=[
+                ToolCapability(tool_id="echo_test", version="1.0", features={}),
+                ToolCapability(tool_id="blastn", version="real", features={"databases": dbs}),
+            ],
+            resources={"max_cpu": 20, "max_ram_gb": 128},
             storage={},
-            policies={"max_runtime_minutes": int(self.config.get("max_runtime_minutes", 1440))},
+            policies={"max_runtime_minutes": 1440},
         )
 
+
     def validate(self, tool_id: str, inputs: Dict[str, Any], resources: Dict[str, Any]) -> Dict[str, Any]:
         errors = []
 
